@@ -3,7 +3,7 @@
 * Nagios check_game plugin
 * 
 * License: GPL
-* Copyright (c) 2002-2007 Nagios Plugins Development Team
+* Copyright (c) 2002-2014 Nagios Plugins Development Team
 * 
 * Description:
 * 
@@ -30,8 +30,8 @@
 *****************************************************************************/
 
 const char *progname = "check_game";
-const char *copyright = "2002-2007";
-const char *email = "nagiosplug-devel@lists.sourceforge.net";
+const char *copyright = "2002-2014";
+const char *email = "devel@nagios-plugins.org";
 
 #include "common.h"
 #include "utils.h"
@@ -280,7 +280,7 @@ validate_arguments (void)
     qstat_map_field = 3;
 
   if (qstat_ping_field < 0)
-    qstat_ping_field = 5;
+    qstat_ping_field = 6;
 
   return OK;
 }
@@ -312,7 +312,7 @@ print_help (void)
   printf (" %s\n", "-pf");
   printf ("    %s\n", _("Field number in raw qstat output that contains ping time"));
 
-  printf (UT_TIMEOUT, DEFAULT_SOCKET_TIMEOUT);
+  printf (UT_CONN_TIMEOUT, DEFAULT_SOCKET_TIMEOUT);
 
   printf ("\n");
   printf ("%s\n", _("Notes:"));
